==> PPDF_1_2.zip: PubMedPDF/local_search.php <==
<?php
	include "header.php";
	include "style.php";
	include "include/Get_Journal.php";
	($xoopsUser) ? $user = $xoopsUser->uname() : $user = "guest";

	## 귫
	if(@$_POST["Go"]){
		if(@$_POST["title"]) $t = "checked";
		if(@$_POST["abstract"]) $a = "checked";
		if(@$_POST["year"]) $y = "checked";
		if(@$_POST["journal"]) $j = "checked";
		if(@$_POST["selectedJournal0"]) $journal = @$_POST["selectedJournal0"];
		$yfrom = @$_POST["yfrom"];
		$yto = @$_POST["yto"];
		$keyword = @$_POST["keyword"];
		$method = @$_POST["method"];
		if($method == "and"){
			$and = "checked";
			$or = "";
		}else{
			$and = "";
			$or = "checked";
		}

	}elseif(@$_GET["p"]){
		if(@$_GET["ti"] == "y") $t = "checked";
		if(@$_GET["ab"] == "y") $a = "checked";
		if(@$_GET["y"] == "y") $y = "checked";
		if(@$_GET["j"] == "y") $j = "checked";
		if(@$_GET["jn"]) $journal = @$_GET["jn"];
		if(@$_GET["yf"]) $yfrom = intval(@$_GET["yf"]);
		if(@$_GET["yt"]) $yto = intval(@$_GET["yt"]);
		$keyword = @$_GET["k"];
		$method = @$_GET["mt"];
		if($method == "and"){
			$and = "checked";
			$or = "";
		}else{
			$and = "";
			$or = "checked";
		}
	
	}else{
		$and = "checked";
		$t = "checked";
		$a = "checked";
		$y = "";
		$j = "";
	}
	
	## ե
	$localsearch = _MI_LOCALSEARCH;
	echo <<<E
	<div class="pt">$localsearch</div>
	<form action="$_SERVER[PHP_SELF]" method="POST">
	<div class="pc">
	<table style="width:95%">
	<tr>
		<td style="width:70px"><b>Word</b></td>
		<td><input type="text" style="width:95%" name="keyword" value="$keyword"></td>
	</tr>
	<tr>
		<td><b>Target</b></td>
		<td>
			<table>
			<tr>
				<td style="width:70px"><input type="checkbox" name="title" value="y" $t> Title</td>
				<td><input type="checkbox" name="abstract" value="y" $a> Abstract</td>
			</tr>
			<tr>
				<td><input type="checkbox" name="journal" value="y" $j> Journal</td>
				<td>
E;
					Get_Journal(0,$journal);
					echo <<<E
				</td>
			</tr>
			<tr>
				<td><input type="checkbox" name="year" value="y" $y> Year</td>
				<td>
					From <input type="text" size="5" name="yfrom" value="$yfrom"> 
					to <input type="text" size="5" name="yto" value="$yto">
				</td>
			</tr>
			</table>
		</td>
	</tr>
	<tr>
		<td><b>Method</b></td>
		<td>
			<input type="radio" name="method" value="and" $and> AND 
			<input type="radio" name="method" value="or" $or> OR
	</tr>
	<tr>
		<td><br><b>Submit</b></td>
		<td><br><input type="submit" value="submit" name="Go"></td>
	</tr>
	</table>
	</div>
	</form>
E;

	## 
	if(@$_POST["Go"]){
	
		$result = array();
		$result_t = array();
		$result_a = array();
		
		$keyw = rtrim(@$_POST["keyword"]);
		$keyword = explode(" ", $keyw);
		$key_num = count($keyword);

		if($year = @$_POST["year"]){
			if(!$yfrom = @$_POST["yfrom"]) $yfrom = 0000;
			if(!$yto = @$_POST["yto"]) $yto = 9999;
			$y_where = "Year >= '".$yfrom."' and Year <= '".$yto."' and ";
		}else{
			$y_where = "";
		}
		
		if($jouanl = @$_POST["journal"]){
			$j_name = @$_POST["selectedJournal0"];
			$sql = "select * from ".$T_JOURNAL." where Journal='".$j_name."'";
			$res = mysql_query($sql, $conn);
			if(mysql_num_rows($res) > 0){
				$row = mysql_fetch_array($res, MYSQL_ASSOC);
				$j_id = $row["id"];
				$j_where = "Journal='".$j_id."' and ";
			}
		}

		for($i=0; $i<$key_num; $i++){	

			if($title = @$_POST["title"]){
				## title
				//$sql = "select * from ".$T_ID." where ".$y_where." (Title like '%".$keyword[$i]."%' or Title_JP like '%".$keyword[$i]."%')";
				$sql = "select * from ".$T_ID." where ".$y_where.$j_where." Title like '%".$keyword[$i]."%'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) > 0){
					while($row = mysql_fetch_array($res, MYSQL_ASSOC)){					
						$result_t[$row["PMID"]] ++;
					}
				}
			}

			if($abst = @$_POST["abstract"]){
				## Abstract
				$sql = "select * from ".$T_ID." where ".$y_where.$j_where." Abstract like '%".$keyword[$i]."%'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) > 0){
					while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
						$result_a[$row["PMID"]] ++;
					}
				}			
			}	
		}

		## AND
		$mt = @$_POST["method"];
		if($mt == "and"){
			foreach($result_t as $key => $value){
				if($value >= $key_num){
					if(!in_array($key, $result)) $result[] = $key;
				}
			}
			foreach($result_a as $key => $value){
				if($value >= $key_num){
					if(!in_array($key, $result)) $result[] = $key;
				}
			}
	
		## OR
		}else{
			foreach($result_t as $key => $value){
				if(!in_array($key, $result)) $result[] = $key;
			}
			foreach($result_a as $key => $value){
				if(!in_array($key, $result)) $result[] = $key;
			}
		}	

		## ɽ
		if(count($result)){

			# ʾθ̤ӽ
			$t = time();
			$del = $t - 86400;
			$sql = "DELETE FROM ".$T_TMP." WHERE tmp1='lsearch' AND tmp2 < '".$del."'";
			$res = mysql_query($sql, $conn);
			
			# ̤ģ¤Ͽ	
			$r = "";
			for($i=0; $i<count($result); $i++){
				$r .= $result[$i].",";
			}
			$r = substr($r, 0, -1);

			$sql = "INSERT INTO ".$T_TMP." VALUES('lsearch','".$t."','".$r."','')";
			$res = mysql_query($sql, $conn);
			
			$info = array($title, $abst, $year, $yfrom, $yto, $journal, $j_name, $keyw, $mt);
			Show_LSresult($user, $t, $info, 1);

		}else{
			echo "<div class=\"pt\">No Hit</div>";
		}
	}

	if(@$_GET["p"]){
		$info = array(@$_GET["ti"],@$_GET["ab"],@$_GET["y"],@$_GET["yf"],@$_GET["yt"],@$_GET["j"],@$_GET["jn"],@$_GET["k"],@$_GET["mt"],);
		Show_LSresult($user, intval(@$_GET["t"]), $info, intval(@$_GET["p"]));
	}

	# ڡѴؿ
	function Show_LSresult($user, $time, $info, $page){
		include "include/conn.php";
	
		$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='lsearch' AND tmp2='".$time."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);

		$item = explode(",", $row["tmp3"]);
		$num = count($item);
		echo "<div class=\"pt\">$num Hit</div>";
		
		# search info
		$si = "ti=".$info[0]."&ab=".$info[1]."&y=".$info[2]."&yf=".$info[3]."&yt=".$info[4];
		$si.= "&j=".$info[5]."&jn=".$info[6]."&k=".$info[7]."&mt=".$info[8];

		# page count
		$lim = 50;
		$st = ($page - 1) * $lim;
		$prepage = $page - 1;
		if($prepage < 1) $prepage = 1;
		$nextpage = $page + 1;

		$show = array();
		for($i=$st; $i<($st + $lim); $i++){
			if(!($i > ($num - 1))){
				$show[] = $item[$i];
			}
		}

		if($page > 1){
			echo "<a href=\"".$SERVER[PHP_SELF]."?p=".$prepage."&t=".$time."&".$si."\">";
			echo "<img src=\"images/left.png\"></a>";
		}

		for($i=1; $i<=ceil($num/$lim); $i++){
			if($i == $page) $showp = "<b>".$i."</b>";
			else $showp = $i;
			echo "<a href=\"".$SERVER[PHP_SELF]."?p=".$i."&t=".$time."&".$si."\">".$showp."</a>&nbsp;";
		}

		if(($nextpage -1) * $lim < $num){
			echo "<a href=\"".$_SERVER[PHP_SELF]."?p=".$nextpage."&t=".$time."&".$si."\">";
			echo "<img src=\"images/right.png\"></a><br><br>";
		}

		PAPER_DESCRIPTION($show, $user);
	}

	include (XOOPS_ROOT_PATH."/footer.php");
?>

==> PPDF_1_3_1.zip: PubMedPDF/local_search.php <==
<?php
	include "header.php";
	include "style.php";
	include "include/Get_Journal.php";
	($xoopsUser) ? $user = $xoopsUser->uname() : $user = "guest";

	## 귫
	if(@$_POST["Go"]){
		if(@$_POST["title"]) $t = "checked";
		if(@$_POST["abstract"]) $a = "checked";
		if(@$_POST["year"]) $y = "checked";
		if(@$_POST["journal"]) $j = "checked";
		if(@$_POST["selectedJournal0"]) $journal = @$_POST["selectedJournal0"];
		$yfrom = @$_POST["yfrom"];
		$yto = @$_POST["yto"];
		$keyword = @$_POST["keyword"];
		$method = @$_POST["method"];
		if($method == "and"){
			$and = "checked";
			$or = "";
		}else{
			$and = "";
			$or = "checked";
		}

	}elseif(@$_GET["p"]){
		if(@$_GET["ti"] == "y") $t = "checked";
		if(@$_GET["ab"] == "y") $a = "checked";
		if(@$_GET["y"] == "y") $y = "checked";
		if(@$_GET["j"] == "y") $j = "checked";
		if(@$_GET["jn"]) $journal = @$_GET["jn"];
		if(@$_GET["yf"]) $yfrom = intval(@$_GET["yf"]);
		if(@$_GET["yt"]) $yto = intval(@$_GET["yt"]);
		$keyword = @$_GET["k"];
		$method = @$_GET["mt"];
		if($method == "and"){
			$and = "checked";
			$or = "";
		}else{
			$and = "";
			$or = "checked";
		}
	
	}else{
		$and = "checked";
		$t = "checked";
		$a = "checked";
		$y = "";
		$j = "";
	}
	
	## ե
	$localsearch = _MI_LOCALSEARCH;
	echo <<<E
	<div class="pt">$localsearch</div>
	<form action="$_SERVER[PHP_SELF]" method="POST">
	<div class="pc">
	<table style="width:95%">
	<tr>
		<td style="width:70px"><b>Word</b></td>
		<td><input type="text" style="width:95%" name="keyword" value="$keyword"></td>
	</tr>
	<tr>
		<td><b>Target</b></td>
		<td>
			<table>
			<tr>
				<td style="width:90px"><input type="checkbox" name="title" value="y" $t> Title</td>
				<td><input type="checkbox" name="abstract" value="y" $a> Abstract</td>
			</tr>
			<tr>
				<td><input type="checkbox" name="journal" value="y" $j> Journal</td>
				<td>
E;
					Get_Journal(0,$journal);
					echo <<<E
				</td>
			</tr>
			<tr>
				<td><input type="checkbox" name="year" value="y" $y> Year</td>
				<td>
					From <input type="text" size="5" name="yfrom" value="$yfrom"> 
					to <input type="text" size="5" name="yto" value="$yto">
				</td>
			</tr>
			</table>
		</td>
	</tr>
	<tr>
		<td><b>Method</b></td>
		<td>
			<input type="radio" name="method" value="and" $and> AND 
			<input type="radio" name="method" value="or" $or> OR
	</tr>
	<tr>
		<td><br><b>Submit</b></td>
		<td><br><input type="submit" value="submit" name="Go"></td>
	</tr>
	</table>
	</div>
	</form>
E;

	## 
	if(@$_POST["Go"]){
	
		$result = array();
		$result_t = array();
		$result_a = array();
		
		$keyw = rtrim(@$_POST["keyword"]);
		$keyword = explode(" ", $keyw);
		$key_num = count($keyword);

		if($year = @$_POST["year"]){
			if(!$yfrom = @$_POST["yfrom"]) $yfrom = 0000;
			if(!$yto = @$_POST["yto"]) $yto = 9999;
			$y_where = "Year >= '".$yfrom."' and Year <= '".$yto."' and ";
		}else{
			$y_where = "";
		}
		
		if($jouanl = @$_POST["journal"]){
			$j_name = @$_POST["selectedJournal0"];
			$sql = "select * from ".$T_JOURNAL." where Journal='".$j_name."'";
			$res = mysql_query($sql, $conn);
			if(mysql_num_rows($res) > 0){
				$row = mysql_fetch_array($res, MYSQL_ASSOC);
				$j_id = $row["id"];
				$j_where = "Journal='".$j_id."' and ";
			}
		}

		for($i=0; $i<$key_num; $i++){	

			if($title = @$_POST["title"]){
				## title
				//$sql = "select * from ".$T_ID." where ".$y_where." (Title like '%".$keyword[$i]."%' or Title_JP like '%".$keyword[$i]."%')";
				$sql = "select * from ".$T_ID." where ".$y_where.$j_where." Title like '%".$keyword[$i]."%'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) > 0){
					while($row = mysql_fetch_array($res, MYSQL_ASSOC)){					
						$result_t[$row["PMID"]] ++;
					}
				}
			}

			if($abst = @$_POST["abstract"]){
				## Abstract
				$sql = "select * from ".$T_ID." where ".$y_where.$j_where." Abstract like '%".$keyword[$i]."%'";
				$res = mysql_query($sql, $conn);
				if(mysql_num_rows($res) > 0){
					while($row = mysql_fetch_array($res, MYSQL_ASSOC)){
						$result_a[$row["PMID"]] ++;
					}
				}			
			}	
		}

		## AND
		$mt = @$_POST["method"];
		if($mt == "and"){
			foreach($result_t as $key => $value){
				if($value >= $key_num){
					if(!in_array($key, $result)) $result[] = $key;
				}
			}
			foreach($result_a as $key => $value){
				if($value >= $key_num){
					if(!in_array($key, $result)) $result[] = $key;
				}
			}
	
		## OR
		}else{
			foreach($result_t as $key => $value){
				if(!in_array($key, $result)) $result[] = $key;
			}
			foreach($result_a as $key => $value){
				if(!in_array($key, $result)) $result[] = $key;
			}
		}	

		## ɽ
		if(count($result)){

			# ʾθ̤ӽ
			$t = time();
			$del = $t - 86400;
			$sql = "DELETE FROM ".$T_TMP." WHERE tmp1='lsearch' AND tmp2 < '".$del."'";
			$res = mysql_query($sql, $conn);
			
			# ̤ģ¤Ͽ	
			$r = "";
			for($i=0; $i<count($result); $i++){
				$r .= $result[$i].",";
			}
			$r = substr($r, 0, -1);

			$sql = "INSERT INTO ".$T_TMP." VALUES('lsearch','".$t."','".$r."','')";
			$res = mysql_query($sql, $conn);
			
			$info = array($title, $abst, $year, $yfrom, $yto, $journal, $j_name, $keyw, $mt);
			Show_LSresult($user, $t, $info, 1);

		}else{
			echo "<div class=\"pt\">No Hit</div>";
		}
	}

	if(@$_GET["p"]){
		$info = array(@$_GET["ti"],@$_GET["ab"],@$_GET["y"],@$_GET["yf"],@$_GET["yt"],@$_GET["j"],@$_GET["jn"],@$_GET["k"],@$_GET["mt"],);
		Show_LSresult($user, intval(@$_GET["t"]), $info, intval(@$_GET["p"]));
	}

	# ڡѴؿ
	function Show_LSresult($user, $time, $info, $page){
		include "include/conn.php";
	
		$sql = "SELECT * FROM ".$T_TMP." WHERE tmp1='lsearch' AND tmp2='".$time."'";
		$res = mysql_query($sql, $conn);
		$row = mysql_fetch_array($res, MYSQL_ASSOC);

		$item = explode(",", $row["tmp3"]);
		$num = count($item);
		echo "<div class=\"pt\">$num Hit</div>";
		
		# search info
		$si = "ti=".$info[0]."&ab=".$info[1]."&y=".$info[2]."&yf=".$info[3]."&yt=".$info[4];
		$si.= "&j=".$info[5]."&jn=".$info[6]."&k=".$info[7]."&mt=".$info[8];

		# page count
		$lim = 50;
		$st = ($page - 1) * $lim;
		$prepage = $page - 1;
		if($prepage < 1) $prepage = 1;
		$nextpage = $page + 1;

		$show = array();
		for($i=$st; $i<($st + $lim); $i++){
			if(!($i > ($num - 1))){
				$show[] = $item[$i];
			}
		}

		if($page > 1){
			echo "<a href=\"".$SERVER[PHP_SELF]."?p=".$prepage."&t=".$time."&".$si."\">";
			echo "<img src=\"images/left.png\"></a>";
		}

		for($i=1; $i<=ceil($num/$lim); $i++){
			if($i == $page) $showp = "<b>".$i."</b>";
			else $showp = $i;
			echo "<a href=\"".$SERVER[PHP_SELF]."?p=".$i."&t=".$time."&".$si."\">".$showp."</a>&nbsp;";
		}

		if(($nextpage -1) * $lim < $num){
			echo "<a href=\"".$_SERVER[PHP_SELF]."?p=".$nextpage."&t=".$time."&".$si."\">";
			echo "<img src=\"images/right.png\"></a><br><br>";
		}

		PAPER_DESCRIPTION($show, $user, $perm);
	}

	include (XOOPS_ROOT_PATH."/footer.php");
?>
